/*
*     ___                       ____ ___
*    / _ \___ _    _____ ____  |_  // _ \
*   / ___/ _ \ |/|/ / -_) __/ _/_ </ // /
*  /_/   \___/__,__/\__/_/   /____/____/
*
*
*   Original Code by John Garrison
*   Written August 29, 1999
*   To be released under the LGPL
*
*   Setting of OpenGL graphics modes and buffers.
*
*   See LICENSE.TXT for more LGPL info
*/

#ifndef _p3dgfx_H
#define _p3dgfx_H

#ifdef __cplusplus
extern "C" {
#endif

#include <math.h>
#include <GL/gl.h>
#include <GL/glu.h>
#include <GL/glut.h>

#define P3D_NOSPLIT 0
#define P3D_HORIZONTAL 1
#define P3D_VERTICAL 2
#define P3D_FOURWAY 3	

#include "power3d.h"

typedef struct _color{
   float r;
   float g;
   float b;
   float a;
}P3D_Color;

typedef GLbitfield P3D_Bitfield;

int P3D_SetGFXMode (int Width, int Height, char *Title, int Bpp, int StencilFlag);

int P3D_ShowDoubleBuffer();

int P3D_Clear();
P3D_Color P3D_CreateColor (float R, float G, float B, float Alpha);
int P3D_SetScreen(float W, float H, float MinDepth, float MaxDepth, int Split, int Section);

#ifdef __cplusplus
};
#endif

#endif
